struct DefaultPolicy(PolicyType);Expand description
A Policy that uses the default filtering behavior for any policy type.
Tuple Fields
0: PolicyTypeTrait Implementations
Sourceimpl Policy for DefaultPolicy
impl Policy for DefaultPolicy
Sourcefn policy_type(&self) -> PolicyType
fn policy_type(&self) -> PolicyType
Returns the policy type this definition handles.
Sourcefn exempt_roles(&self) -> &[OrganizationUserType]
fn exempt_roles(&self) -> &[OrganizationUserType]
Returns the organization roles that are exempt from this policy. Read more
Sourcefn exempt_providers(&self) -> bool
fn exempt_providers(&self) -> bool
Returns whether provider users are exempt from this policy. Read more
Sourcefn applicable_statuses(&self) -> &[OrganizationUserStatusType]
fn applicable_statuses(&self) -> &[OrganizationUserStatusType]
Returns the organization membership statuses for which this policy applies. Read more